@@ -123,6 +123,7 @@ init (GnomePilotCDialog *gpcd)
 	gnome_dialog_close_hides (GNOME_DIALOG (priv->dialog), TRUE);
 	
  error:
+	;
 }
 
 
@@ -206,7 +207,7 @@ fill_widgets (GnomePilotCDialog *gpcd)
 
 		} else if (gnome_pilot_conduit_create_settings_window (priv->state->conduit, priv->options_frame) == 500) { /* < 0) { */
 			gchar *msg = _("Unable to create pilot settings window. Incorrect conduit configuration.");
-			error_dialog (msg);
+			error_dialog (GTK_WINDOW (priv->dialog), msg);
 			
 			/* Self healing. Will not try again for this run of the capplet */
 			gnome_pilot_conduit_management_destroy_conduit (priv->state->management, &priv->state->conduit);
