@@ -285,19 +285,25 @@ void
 insert_username_callback (GtkEditable *editable, const gchar *text,
 			  gint len, gint *position, void *data)
 {
-	gint i;
+	gunichar utf8_char;
 
 	/* need to make sure that existing entry starts with a letter */
 	/* since valid usernames must start with a letter             */
 	if (*position == 0 && len > 0) {
-		if (!isalpha (text[0]))
+		utf8_char = g_utf8_get_char_validated (text, -1);
+		if (!g_unichar_isalpha (utf8_char)) {
 			gtk_signal_emit_stop_by_name (GTK_OBJECT (editable), "insert_text");
+		}
 	} else {
+		gchar *p = (char *) text; 
 		/* rest of username can be alphanumeric */
-		for (i = 0; i < len; i++) {
-			if (!(isalnum (text[i]) || text[i] == ' '))
+		while (p && *p) {
+			utf8_char = g_utf8_get_char_validated (p, -1);
+			if (!g_unichar_isalnum (utf8_char) && !g_unichar_isspace (utf8_char)) {
 				gtk_signal_emit_stop_by_name (GTK_OBJECT (editable), 
 							     "insert_text");
+			}
+			p = g_utf8_find_next_char (p, NULL);
 		}
 	}
 }
