@@ -313,7 +313,7 @@ set_user ()
 };
 
 static void 
-get_system_info () 
+get_system_info (void) 
 {
 	gint err;
 	gboolean abort = FALSE;
@@ -417,7 +417,7 @@ main (int argc, char *argv[]) {
 		gnome_pilot_client_monitor_off_all_pilots (gpc);		
 	} else if (arg_getinfo) {
 		g_message ("Get SystemInfo");
-		get_system_info (gpc);
+		get_system_info ();
 	}
 
 	return 0;
